@@ -21,10 +21,12 @@ class WindowsVolumeForm(NetBoxModelForm):
 
     drive_name = CharField(
         label="Drive Name",
+        help_text="The drive name of the windows volume e.g. D",
     )
     fs = DynamicModelChoiceField(
         queryset=Filesystem.objects.all(),
         label="Filesystem Name",
+        help_text="The Filesystem of the Volume e.g. NTFS",
     )
     drives = DynamicModelMultipleChoiceField(
         queryset=Drive.objects.all(),
