@@ -2,7 +2,6 @@ from django.db import models
 from django.urls import reverse
 
 from netbox.models import NetBoxModel
-from netbox.search import SearchIndex, register_search
 
 
 class Drive(NetBoxModel):
@@ -27,7 +26,7 @@ class Drive(NetBoxModel):
         blank=True,
     )
 
-    clone_fields = ["size", "cluster", "virtual_machine", "description"]
+    clone_fields = ["size", "identifier", "cluster", "virtual_machine", "description"]
 
     prerequisite_models = (
         'virtualization.Cluster',
